@@ -1,16 +1,19 @@
 """Define a V2 (original) SimpliSafe system."""
-from typing import Dict
+from __future__ import annotations
 
+from simplipy.const import LOGGER
+from simplipy.device.sensor.v2 import SensorV2
 from simplipy.system import (
     CONF_DURESS_PIN,
     CONF_MASTER_PIN,
     DEFAULT_MAX_USER_PINS,
     System,
     SystemStates,
+    get_device_type_from_data,
 )
 
 
-def create_pin_payload(pins: dict) -> Dict[str, Dict[str, Dict[str, str]]]:
+def create_pin_payload(pins: dict) -> dict[str, dict[str, dict[str, str]]]:
     """Create the request payload to send for updating PINs."""
     duress_pin = pins.pop(CONF_DURESS_PIN)
     master_pin = pins.pop(CONF_MASTER_PIN)
@@ -29,26 +32,25 @@ def create_pin_payload(pins: dict) -> Dict[str, Dict[str, Dict[str, str]]]:
             "pin": "",
         }
 
+    LOGGER.debug("PIN payload: %s", payload)
+
     return payload
 
 
 class SystemV2(System):
     """Define a V2 (original) system."""
 
-    async def _update_entity_data(self, cached: bool = True) -> None:
-        """Update sensors to the latest values."""
-        sensor_resp = await self._api.request(
-            "get",
-            f"subscriptions/{self.system_id}/settings",
-            params={"settingsType": "all", "cached": str(cached).lower()},
+    async def _async_set_state(self, value: SystemStates) -> None:
+        """Set the state of the system."""
+        await self._api.request(
+            "post",
+            f"subscriptions/{self.system_id}/state",
+            params={"state": value.name},
         )
 
-        for entity in sensor_resp.get("settings", {}).get("sensors", []):
-            if not entity:
-                continue
-            self.entity_data[entity["serial"]] = entity
+        self._state = value
 
-    async def _set_updated_pins(self, pins: dict) -> None:
+    async def _async_set_updated_pins(self, pins: dict) -> None:
         """Post new PINs."""
         await self._api.request(
             "post",
@@ -56,18 +58,30 @@ class SystemV2(System):
             json=create_pin_payload(pins),
         )
 
-    async def _set_state(self, value: SystemStates) -> None:
-        """Set the state of the system."""
-        state_resp = await self._api.request(
-            "post",
-            f"subscriptions/{self.system_id}/state",
-            params={"state": value.name},
+    async def _async_update_device_data(self, cached: bool = True) -> None:
+        """Update sensors to the latest values."""
+        sensor_resp = await self._api.request(
+            "get",
+            f"subscriptions/{self.system_id}/settings",
+            params={"settingsType": "all", "cached": str(cached).lower()},
         )
 
-        if state_resp["success"]:
-            self._state = SystemStates[state_resp["requestedState"]]
+        for sensor in sensor_resp.get("settings", {}).get("sensors", []):
+            if not sensor:
+                continue
+            self.sensor_data[sensor["serial"]] = sensor
 
-    async def get_pins(self, cached: bool = True) -> Dict[str, str]:
+    async def _async_update_settings_data(self, cached: bool = True) -> None:
+        """Update all settings data."""
+        pass
+
+    def generate_device_objects(self) -> None:
+        """Generate device objects for this system."""
+        for serial, data in self.sensor_data.items():
+            sensor_type = get_device_type_from_data(data)
+            self.sensors[serial] = SensorV2(self, sensor_type, serial)
+
+    async def async_get_pins(self, cached: bool = True) -> dict[str, str]:
         """Return all of the set PINs, including master and duress.
 
         The ``cached`` parameter determines whether the SimpliSafe Cloud uses the last
@@ -75,7 +89,7 @@ class SystemV2(System):
 
         :param cached: Whether to used cached data.
         :type cached: ``bool``
-        :rtype: ``Dict[str, str]``
+        :rtype: ``dict[str, str]``
         """
         pins_resp = await self._api.request(
             "get",
